<?php

namespace Startup\Forum\Http\Controllers;

use App\Http\Controllers\PublicApiController as PublicController;
use Startup\Forum\Interfaces\ForumRepositoryInterface;
use Startup\Forum\Repositories\Presenter\ForumItemTransformer;

/**
 * Pubic API controller class.
 */
class ForumPublicApiController extends PublicController
{
    /**
     * Constructor.
     *
     * @param type \Startup\Forum\Interfaces\ForumRepositoryInterface $forum
     *
     * @return type
     */
    public function __construct(ForumRepositoryInterface $forum)
    {
        $this->repository = $forum;
        parent::__construct();
    }

    /**
     * Show forum's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $forums = $this->repository
            ->setPresenter('\\Startup\\Forum\\Repositories\\Presenter\\ForumListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $forums['code'] = 2000;
        return response()->json($forums)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show forum.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $forum = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($forum)) {
            $forum         = $this->itemPresenter($module, new ForumItemTransformer);
            $forum['code'] = 2001;
            return response()->json($forum)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
